@@ -30,7 +30,8 @@ def gen_post_filename(filename):
 def strong_ensure(filename):
 	if os.path.exists(filename) is False: return False
 	try:
-		os.stat(filename)
+		with open(filename, "br") as f:
+			pass
 	except:
 		return False
 	return True
